@@ -21,7 +21,9 @@ class Antispamclass(ClassTypes):
     token: str
     userid: int
     reason: str
-    def __init__(self, reason: str, token: str, userid: int, **kwargs) -> None:
+    banned: str
+    def __init__(self, banned: str, reason: str, token: str, userid: int, **kwargs) -> None:
         self.token = token
         self.userid = userid
         self.reason = reason
+        self.banned = banned
